

  function [fgax,fkm,cb] = plotmodel(ifg,y1,y2,z1,z2,c1,c2,NY,NZB,YDIS,ZDIS,RHO,...
                          nstm,sltm,nste,slte,nstp,sltp,hsv2);

  figure(ifg); set(gcf,'Name','RESISTIVITY MODEL', ...
                   'Unit','Normalized','Position',[0. 0.4 0.5 0.5]);
  clf; colormap(hsv2);

  yrg = y2-y1;
  zrg = z1-z2;
  ysz = 0.7; zsz = 0.7; yst = 0.15; zst = 0.15;
  if (yrg > zrg), zsz = zsz*(zrg/yrg); zst = (0.7 - zsz)/2. + zst;
    fgax = axes('Position',[yst zst ysz zsz]); end;
  if (yrg < zrg), ysz = ysz*(yrg/zrg); yst = (0.7 - ysz)/2. + yst;
    fgax = axes('Position',[yst zst ysz zsz]); end;
  if (yrg == zrg), fgax = axes('Position',[yst zst ysz zsz]); end;

  fkm = 0; yds = YDIS; zds = ZDIS;
  if (yrg > 10000.) | (zrg > 10000.), 
    fkm = 1; yds = YDIS/1000; zds = ZDIS/1000; 
  end;
  
  resismodel = surface(yds(1:NY+1),-zds(1:NZB+1),log10(RHO(1:NZB+1,1:NY+1)));
  cb = colorbar('vert');
  set(resismodel,'FaceColor','flat');
  set(resismodel,'EdgeColor','none');

  if (fkm == 0);
    set(fgax,'XLim',[y1 y2]);   set(fgax,'YLim',[-z1 -z2]);
  else
    set(fgax,'XLim',[y1/1000. y2/1000.]);   set(fgax,'YLim',[-z1/1000. -z2/1000.]);
  end
  set(fgax,'CLim',[c1 c2]);
  set(fgax,'DataAspectRatio',[1 1 1]);

  if (fkm == 0), xlabel('Distance along profile (m)');
  else           xlabel('Distance along profile (km)'); end;
  if (fkm == 0), ylabel('Depth (m)');
  else           ylabel('Depth (km)'); end;

  hold
  itx = 0; isx = 0;
  if (nstm ~= 0),
    for is = 1:nstm,
      if (sltm(is) >= y1) & (sltm(is) <= y2), 
        if (fkm == 0), text(sltm(is),isx,'v', ...
           'VerticalAlignment','Bottom','HorizontalAlignment','Center'); 
        else text(sltm(is)/1000.,isx/1000.,'v', ...
           'VerticalAlignment','Bottom','HorizontalAlignment','Center'); end;
      end; 
    end;
    if (fkm == 0), text(y2+0.1*yrg,isx,'TM', ...
           'VerticalAlignment','Bottom','HorizontalAlignment','Center'); 
    else text((y2+0.1*yrg)/1000.,isx/1000.,'TM', ...
           'VerticalAlignment','Bottom','HorizontalAlignment','Center'); end;
    itx = itx + 1;
  end;
  if (nste ~= 0),
    if (itx == 0), isx = 0; end;
    if (itx == 1), isx = zrg*0.05; end;
    for is = 1:nste, 
      if (slte(is) >= y1) & (slte(is) <= y2), 
        if (fkm == 0), text(slte(is),isx,'v', ...
             'VerticalAlignment','Bottom','HorizontalAlignment','Center'); 
        else text(slte(is)/1000.,isx/1000.,'v', ...
             'VerticalAlignment','Bottom','HorizontalAlignment','Center'); end;
      end;
    end;
    if (fkm == 0), text(y2+0.1*yrg,isx,'TE', ...
                   'VerticalAlignment','Bottom','HorizontalAlignment','Center'); 
    else text((y2+0.1*yrg)/1000.,isx/1000.,'TE', ...
         'VerticalAlignment','Bottom','HorizontalAlignment','Center'); end;
    itx = itx + 1;
  end;
  if (nstp ~= 0),
    if (itx == 0), isx = 0; end;
    if (itx == 1), isx = zrg*0.05; end;
    if (itx == 2), isx = zrg*0.10; end;
    for is = 1:nstp, 
      if (sltp(is) >= y1) & (sltp(is) <= y2), 
        if (fkm == 0), text(sltp(is),isx,'v', ...
                       'VerticalAlignment','Bottom','HorizontalAlignment','Center'); 
        else text(sltp(is)/1000.,isx/1000.,'v', ...
             'VerticalAlignment','Bottom','HorizontalAlignment','Center'); end;
      end;
    end;
    if (fkm == 0), text(y2+0.1*yrg,isx,'TP', ...
                   'VerticalAlignment','Bottom','HorizontalAlignment','Center'); 
    else text((y2+0.1*yrg)/1000.,isx/1000.,'TP', ...
         'VerticalAlignment','Bottom','HorizontalAlignment','Center'); end;
  end;
  hold off;

return
